@@ -38,6 +38,13 @@ int main() {
     die_unless_throws(die_unequal_eps6(-0.0001, NAN), tlx::DieException);
     die_unequal_eps6(NAN, NAN);
 
+    die_unless_throws(die_verbose_unless(false, "bad"), tlx::DieException);
+    die_unless_throws(die_verbose_if(true, "bad"), tlx::DieException);
+    die_unless_throws(die_verbose_unequal(1, 2, "bad"), tlx::DieException);
+    die_unless_throws(die_verbose_unequal_eps6(NAN, -0.0001, "bad"),
+                      tlx::DieException);
+    die_unless_throws(die_verbose_equal(2, 2, "bad"), tlx::DieException);
+
     return 0;
 }
 
