@@ -15,9 +15,13 @@
 //! Simple string manipulations
 
 /*[[[perl
-print "#include <$_>\n" foreach sort glob("tlx/string/"."*.hpp");
+my %exclude = ("tlx/string/appendline.hpp" => 1,
+               "tlx/string/ssprintf_generic.hpp" => 1);
+print "#include <$_>\n"
+    foreach grep {!$exclude{$_}} sort glob("tlx/string/"."*.hpp");
 ]]]*/
 #include <tlx/string/base64.hpp>
+#include <tlx/string/bitdump.hpp>
 #include <tlx/string/compare_icase.hpp>
 #include <tlx/string/contains.hpp>
 #include <tlx/string/contains_word.hpp>
@@ -28,7 +32,11 @@ print "#include <$_>\n" foreach sort glob("tlx/string/"."*.hpp");
 #include <tlx/string/escape_uri.hpp>
 #include <tlx/string/expand_environment_variables.hpp>
 #include <tlx/string/extract_between.hpp>
+#include <tlx/string/format_iec_units.hpp>
 #include <tlx/string/format_si_iec_units.hpp>
+#include <tlx/string/format_si_units.hpp>
+#include <tlx/string/hash_djb2.hpp>
+#include <tlx/string/hash_sdbm.hpp>
 #include <tlx/string/hexdump.hpp>
 #include <tlx/string/index_of.hpp>
 #include <tlx/string/join.hpp>
@@ -41,7 +49,9 @@ print "#include <$_>\n" foreach sort glob("tlx/string/"."*.hpp");
 #include <tlx/string/replace.hpp>
 #include <tlx/string/split.hpp>
 #include <tlx/string/split_quoted.hpp>
+#include <tlx/string/split_view.hpp>
 #include <tlx/string/split_words.hpp>
+#include <tlx/string/ssprintf.hpp>
 #include <tlx/string/starts_with.hpp>
 #include <tlx/string/to_lower.hpp>
 #include <tlx/string/to_upper.hpp>
