@@ -1,5 +1,5 @@
 /*
- * CSRMatrix.h
+ * CSRMatrix.hpp
  *
  *  Created on: May 6, 2015
  *      Author: Michael Wegner (michael.wegner@student.kit.edu)
@@ -9,6 +9,7 @@
 #define NETWORKIT_ALGEBRAIC_CSR_MATRIX_HPP_
 
 #include <vector>
+
 #include <networkit/Globals.hpp>
 #include <networkit/algebraic/AlgebraicGlobals.hpp>
 #include <networkit/algebraic/Vector.hpp>
@@ -23,7 +24,7 @@ namespace NetworKit {
  * The CSRMatrix class represents a sparse matrix stored in CSR-Format (i.e. compressed sparse row).
  * If speed is important, use this CSRMatrix instead of the Matrix class.
  */
-class CSRMatrix {
+class CSRMatrix final {
 private:
     std::vector<index> rowIdx;
     std::vector<index> columnIdx;
@@ -70,7 +71,7 @@ public:
      * @param dimension Defines how many rows and columns this matrix has.
      * @param zero The zero element (default = 0.0).
      */
-    CSRMatrix(const count dimension, const double zero = 0.0);
+    CSRMatrix(count dimension, double zero = 0.0);
 
     /**
      * Constructs the CSRMatrix with size @a nRows x @a nCols.
@@ -78,7 +79,7 @@ public:
      * @param nCols Number of columns.
      * @param zero The zero element (default = 0.0).
      */
-    CSRMatrix(const count nRows, const count nCols, const double zero = 0.0);
+    CSRMatrix(count nRows, count nCols, double zero = 0.0);
 
     /**
      * Constructs the @a dimension x @a dimension Matrix from the elements at position @a positions with values @values.
@@ -87,7 +88,7 @@ public:
      * @param zero The zero element (default is 0.0).
      * @param isSorted True, if the triplets are sorted per row. Default is false.
      */
-    CSRMatrix(const count dimension, const std::vector<Triplet>& triplets, const double zero = 0.0, bool isSorted = false);
+    CSRMatrix(count dimension, const std::vector<Triplet>& triplets, double zero = 0.0, bool isSorted = false);
 
     /**
      * Constructs the @a nRows x @a nCols Matrix from the elements at position @a positions with values @values.
@@ -97,7 +98,7 @@ public:
      * @param zero The zero element (default is 0.0).
      * @param isSorted True, if the triplets are sorted per row. Default is false.
      */
-    CSRMatrix(const count nRows, const count nCols, const std::vector<Triplet>& triplets, const double zero = 0.0, bool isSorted = false);
+    CSRMatrix(count nRows, count nCols, const std::vector<Triplet>& triplets, double zero = 0.0, bool isSorted = false);
 
     /**
      * Constructs the @a nRows x @a nCols Matrix from the elements stored in @a columnIdx and @a values. @a columnIdx and @a values store the colums and values by row.
@@ -108,7 +109,7 @@ public:
      * @param zero The zero element (default is 0.0).
      * @param isSorted True if the column indices in @a columnIdx are sorted in every row.
      */
-    CSRMatrix(const count nRows, const count nCols, const std::vector<std::vector<index>> &columnIdx, const std::vector<std::vector<double>> &values, const double zero = 0.0, bool isSorted = false);
+    CSRMatrix(count nRows, count nCols, const std::vector<std::vector<index>> &columnIdx, const std::vector<std::vector<double>> &values, double zero = 0.0, bool isSorted = false);
 
     /**
      * Constructs the @a nRows x @a nCols Matrix from the elements at position @a positions with values @values.
@@ -120,7 +121,7 @@ public:
      * @param zero The zero element (default is 0.0).
      * @param isSorted True, if the triplets are sorted per row. Default is false.
      */
-    CSRMatrix(const count nRows, const count nCols, const std::vector<index>& rowIdx, const std::vector<index>& columnIdx, const std::vector<double>& nonZeros, const double zero = 0.0, bool isSorted = false);
+    CSRMatrix(count nRows, count nCols, const std::vector<index>& rowIdx, const std::vector<index>& columnIdx, const std::vector<double>& nonZeros, double zero = 0.0, bool isSorted = false);
 
     /** Default copy constructor */
     CSRMatrix (const CSRMatrix &other) = default;
@@ -129,7 +130,7 @@ public:
     CSRMatrix (CSRMatrix &&other) = default;
 
     /** Default destructor */
-    virtual ~CSRMatrix() = default;
+    ~CSRMatrix() = default;
 
     /** Default move assignment operator */
     CSRMatrix& operator=(CSRMatrix &&other) = default;
@@ -190,7 +191,7 @@ public:
      * @param i The row index.
      * @return Number of non-zeros in row @a i.
      */
-    count nnzInRow(const index i) const;
+    count nnzInRow(index i) const;
 
     /**
      * @return Number of non-zeros in this matrix.
@@ -200,13 +201,13 @@ public:
     /**
      * @return Value at matrix position (i,j).
      */
-    double operator()(const index i, const index j) const;
+    double operator()(index i, index j) const;
 
     /**
      * Set the matrix at position (@a i, @a j) to @a value.
      * @note This operation can be linear in the number of non-zeros due to vector element movements
      */
-    void setValue(const index i, const index j, const double value);
+    void setValue(index i, index j, double value);
 
     /**
      * Sorts the column indices in each row for faster access.
@@ -221,12 +222,12 @@ public:
     /**
      * @return Row @a i of this matrix as vector.
      */
-    Vector row(const index i) const;
+    Vector row(index i) const;
 
     /**
      * @return Column @a j of this matrix as vector.
      */
-    Vector column(const index j) const;
+    Vector column(index j) const;
 
     /**
      * @return The main diagonal of this matrix.
@@ -262,13 +263,13 @@ public:
      * Multiplies this matrix with a scalar specified in @a scalar and returns the result.
      * @return The result of multiplying this matrix with @a scalar.
      */
-    CSRMatrix operator*(const double &scalar) const;
+    CSRMatrix operator*(double scalar) const;
 
     /**
      * Multiplies this matrix with a scalar specified in @a scalar.
      * @return Reference to this matrix.
      */
-    CSRMatrix& operator*=(const double &scalar);
+    CSRMatrix& operator*=(double scalar);
 
     /**
      * Multiplies this matrix with @a vector and returns the result.
@@ -286,13 +287,13 @@ public:
      * Divides this matrix by a divisor specified in @a divisor and returns the result in a new matrix.
      * @return The result of dividing this matrix by @a divisor.
      */
-    CSRMatrix operator/(const double &divisor) const;
+    CSRMatrix operator/(double divisor) const;
 
     /**
      * Divides this matrix by a divisor specified in @a divisor.
      * @return Reference to this matrix.
      */
-    CSRMatrix& operator/=(const double &divisor);
+    CSRMatrix& operator/=(double divisor);
 
     /**
      * Computes @a A @a binaryOp @a B on the elements of matrix @a A and matrix @a B.
@@ -557,7 +558,7 @@ template<typename L> inline CSRMatrix CSRMatrix::binaryOperator(const CSRMatrix
 }
 
 template<typename F>
-void CSRMatrix::apply(const F unaryElementFunction) {
+void CSRMatrix::apply(F unaryElementFunction) {
 #pragma omp parallel for
     for (omp_index k = 0; k < static_cast<omp_index>(nonZeros.size()); ++k) {
         nonZeros[k] = unaryElementFunction(nonZeros[k]);
