@@ -5,9 +5,13 @@
  *      Author: Henning
  */
 
+// networkit-format
+
 #ifndef NETWORKIT_CENTRALITY_PAGE_RANK_HPP_
 #define NETWORKIT_CENTRALITY_PAGE_RANK_HPP_
 
+#include <limits>
+
 #include <networkit/centrality/Centrality.hpp>
 
 namespace NetworKit {
@@ -19,12 +23,11 @@ namespace NetworKit {
  * directed graphs; we follow the verbal description, which requires to sum over the incoming
  * edges (as opposed to outgoing ones).
  */
-class PageRank: public Centrality {
-protected:
-    double damp;
-    double tol;
+class PageRank final : public Centrality {
 
 public:
+    enum Norm { L1Norm, L2Norm };
+
     /**
      * Constructs the PageRank class for the Graph @a G
      *
@@ -32,18 +35,41 @@ public:
      * @param[in] damp Damping factor of the PageRank algorithm.
      * @param[in] tol Error tolerance for PageRank iteration.
      */
-    PageRank(const Graph& G, double damp=0.85, double tol = 1e-8);
+    PageRank(const Graph &G, double damp = 0.85, double tol = 1e-8);
 
     /**
      * Computes page rank on the graph passed in constructor.
      */
-    virtual void run();
+    void run() override;
 
     /**
-     * Returns upper bound on the page rank: 1.0. This could be tighter by assuming e.g. a star graph with n nodes.
+     * Returns upper bound on the page rank: 1.0. This could be tighter by assuming e.g. a star
+     * graph with n nodes.
      */
-    virtual double maximum();
+    double maximum() override;
+
+    /**
+     * Return the number of iterations performed by the algorithm.
+     *
+     * @return Number of iterations performed by the algorithm.
+     */
+    count numberOfIterations() const {
+        assureFinished();
+        return iterations;
+    }
+
+    // Maximum number of iterations allowed
+    count maxIterations = std::numeric_limits<count>::max();
+
+    // Norm used as stopping criterion
+    Norm norm = Norm::L2Norm;
+
+private:
+    double damp;
+    double tol;
+    count iterations;
 };
 
 } /* namespace NetworKit */
+
 #endif // NETWORKIT_CENTRALITY_PAGE_RANK_HPP_
