@@ -26,9 +26,9 @@ public:
 
     GraphCoarsening(const Graph& G);
 
-    virtual ~GraphCoarsening() = default;
+    ~GraphCoarsening() override = default;
 
-    virtual void run() = 0;
+    void run() override = 0;
 
     Graph getCoarseGraph() const;
 
@@ -43,7 +43,7 @@ public:
     std::map<node, std::vector<node> > getCoarseToFineNodeMapping() const;
 
 protected:
-    const Graph& G;
+    const Graph* G;
     Graph Gcoarsened;
     std::vector<node> nodeMapping;
 
