@@ -1,5 +1,5 @@
 /*
- * Conductance.h
+ * Conductance.hpp
  *
  *  Created on: 26.02.2014
  *      Author: Henning
@@ -8,9 +8,9 @@
 #ifndef NETWORKIT_COMMUNITY_CONDUCTANCE_HPP_
 #define NETWORKIT_COMMUNITY_CONDUCTANCE_HPP_
 
-#include <networkit/community/QualityMeasure.hpp>
-#include <networkit/community/EdgeCut.hpp>
 #include <networkit/auxiliary/NumericTools.hpp>
+#include <networkit/community/EdgeCut.hpp>
+#include <networkit/community/QualityMeasure.hpp>
 
 namespace NetworKit {
 
@@ -19,13 +19,13 @@ namespace NetworKit {
  * Compute conductance of a 2-partition, i.e. cut size over volume of smaller set (smaller in
  * terms of volume).
  */
-class Conductance: public QualityMeasure {
+class Conductance final : public QualityMeasure {
 public:
     /**
      * @return Conductance of 2-partition @a zeta in graph @a G.
      * Requires cluster IDs to be either 0 or 1.
      */
-    virtual double getQuality(const Partition& zeta, const Graph& G);
+    double getQuality(const Partition& zeta, const Graph& G) override;
 };
 
 } /* namespace NetworKit */
