@@ -1,5 +1,5 @@
 /*
- * EdgeCut.h
+ * EdgeCut.hpp
  *
  *  Created on: Jun 20, 2013
  *      Author: Henning
@@ -15,9 +15,9 @@ namespace NetworKit {
 /**
  * @ingroup community
  */
-class EdgeCut: public QualityMeasure {
+class EdgeCut final : public QualityMeasure {
 public:
-    virtual double getQuality(const Partition& zeta, const Graph& G);
+    double getQuality(const Partition& zeta, const Graph& G) override;
 };
 
 } /* namespace NetworKit */
