@@ -1,5 +1,5 @@
 /*
- * LPDegreeOrdered.h
+ * LPDegreeOrdered.hpp
  *
  *  Created on: 24.09.2013
  *      Author: cls
@@ -19,30 +19,29 @@ typedef index label; // a label is the same as a cluster id
  * Label propagation-based community detection algorithm which
  * processes nodes in increasing order of node degree.
  */
-class LPDegreeOrdered: public CommunityDetectionAlgorithm {
+class LPDegreeOrdered final : public CommunityDetectionAlgorithm {
 private:
-    count nIterations = 0;	//!< number of iterations in last run
-
+    count nIterations = 0; //!< number of iterations in last run
 
 public:
     /**
      * Constructor to the degree ordered label propagation community detection algorithm.
      *
-     * @param[in]	G	input graph
+     * @param[in] G input graph
      */
     LPDegreeOrdered(const Graph& G);
 
     /**
      * Detect communities.
      */
-    virtual void run() override;
+    void run() override;
 
     /**
     * Get number of iterations in last run.
     *
     * @return Number of iterations.
     */
-    virtual count numberOfIterations();
+    count numberOfIterations();
 
     std::string toString() const override;
 
