@@ -1,5 +1,5 @@
 /*
- * NMIDistance.h
+ * NMIDistance.hpp
  *
  *  Created on: 30.04.2013
  *      Author: cls
@@ -8,7 +8,6 @@
 #ifndef NETWORKIT_COMMUNITY_NMI_DISTANCE_HPP_
 #define NETWORKIT_COMMUNITY_NMI_DISTANCE_HPP_
 
-
 #include <networkit/community/DissimilarityMeasure.hpp>
 
 namespace NetworKit {
@@ -19,12 +18,11 @@ namespace NetworKit {
  * Normalized Mutual Information.
  *
  */
-class NMIDistance: public DissimilarityMeasure {
+class NMIDistance final: public DissimilarityMeasure {
 
 public:
 
-
-    virtual double getDissimilarity(const Graph& G, const Partition& zeta, const Partition& eta);
+    double getDissimilarity(const Graph& G, const Partition& zeta, const Partition& eta) override;
 
 };
 
