@@ -1,8 +1,8 @@
 /*
- * RandMeasure.h
+ * NodeStructuralRandMeasure.hpp
  *
  *  Created on: 19.01.2013
- *      Author: Christian Staudt (christian.staudt@kit.edu)
+ *      Author: Christian Staudt
  */
 
 #ifndef NETWORKIT_COMMUNITY_NODE_STRUCTURAL_RAND_MEASURE_HPP_
@@ -17,12 +17,11 @@ namespace NetworKit {
  * The node-structural Rand measure assigns a similarity value in [0,1]
  * to two partitions of a graph, by considering all pairs of nodes.
  */
-class NodeStructuralRandMeasure: public DissimilarityMeasure {
+class NodeStructuralRandMeasure final: public DissimilarityMeasure {
 
 public:
 
-
-    virtual double getDissimilarity(const Graph &G, const Partition &zeta, const Partition &eta);
+    double getDissimilarity(const Graph &G, const Partition &zeta, const Partition &eta) override;
 
 };
 
