@@ -9,12 +9,12 @@ namespace NetworKit {
  * Class for calculating the intersection of two partitions, i.e. the clustering with the fewest clusters
  * such that each cluster is a subset of a cluster in both partitions.
  */
-class PartitionIntersection {
+class PartitionIntersection final {
     public:
         /**
          * Calculate the intersection of two partitions @a zeta and @a eta
-         * @param zeta	The first partition
-         * @param eta	The second partition
+         * @param zeta The first partition
+         * @param eta The second partition
          * @return The intersection of @a zeta and @a eta
          */
         Partition calculate(const Partition &zeta, const Partition &eta);
@@ -22,5 +22,4 @@ class PartitionIntersection {
 
 } /* namespace NetworKit */
 
-
 #endif // NETWORKIT_COMMUNITY_PARTITION_INTERSECTION_HPP_
