@@ -11,14 +11,14 @@ namespace NetworKit {
  * The value of a cluster is the percentage of stable nodes in the cluster.
  * Larger values indicate that a clustering is more stable and thus better defined.
  */
-class StablePartitionNodes : public LocalPartitionEvaluation {
+class StablePartitionNodes final : public LocalPartitionEvaluation {
 public:
     using LocalPartitionEvaluation::LocalPartitionEvaluation; // inherit constructor
 
     /**
      * Execute the algorithm.
      */
-    virtual void run() override;
+    void run() override;
 
     /**
      * Check if a given node is stable, i.e. more connected to its own partition than to other partitions.
@@ -33,7 +33,7 @@ public:
      *
      * @return false.
      */
-    virtual bool isSmallBetter() const override { return false; }
+    bool isSmallBetter() const override { return false; }
 private:
     std::vector<uint8_t> stableMarker;
 };
