@@ -1,5 +1,5 @@
 /*
- * AdamicAdarDistance.h
+ * AdamicAdarDistance.hpp
  *
  *  Created on: 18.11.2014
  *      Author: Michael Hamann, Gerd Lindner
@@ -8,8 +8,8 @@
 #ifndef NETWORKIT_DISTANCE_ADAMIC_ADAR_DISTANCE_HPP_
 #define NETWORKIT_DISTANCE_ADAMIC_ADAR_DISTANCE_HPP_
 
-#include <networkit/graph/Graph.hpp>
 #include <networkit/distance/NodeDistance.hpp>
+#include <networkit/graph/Graph.hpp>
 
 namespace NetworKit {
 
@@ -17,9 +17,9 @@ namespace NetworKit {
  * @ingroup distance
  * An implementation of the Adamic Adar distance measure.
  */
-class AdamicAdarDistance : public NodeDistance {
+class AdamicAdarDistance final : public NodeDistance {
 
-protected:
+private:
     std::vector<double> aaDistance; //result vector
 
     void removeNode(Graph& graph, node u);
@@ -35,19 +35,19 @@ public:
      * Computes the Adamic Adar distances of all connected pairs of nodes.
      * REQ: Needs to be called before distance() and getEdgeScores() deliver meaningful results!
      */
-    virtual void preprocess();
+     void preprocess() override;
 
     /**
      * Returns the Adamic Adar distance between node @a u and node @a v.
      * @return Adamic Adar distance between the two nodes.
      */
-    virtual double distance(node u, node v);
+     double distance(node u, node v) override;
 
     /**
      * Returns the Adamic Adar distances between all connected nodes.
      * @return Vector containing the Adamic Adar distances between all connected pairs of nodes.
      */
-    virtual std::vector<double> getEdgeScores();
+     std::vector<double> getEdgeScores() override;
 
 };
 
