@@ -1,10 +1,12 @@
 /*
- * ChibaNishizekiQuadrangleEdgeScore.h
+ * ChibaNishizekiQuadrangleEdgeScore.hpp
  *
  *  Created on: 18.11.2014
  *      Author: Michael Hamann, Gerd Lindner
  */
 
+// networkit-format
+
 #ifndef NETWORKIT_EDGESCORES_CHIBA_NISHIZEKI_QUADRANGLE_EDGE_SCORE_HPP_
 #define NETWORKIT_EDGESCORES_CHIBA_NISHIZEKI_QUADRANGLE_EDGE_SCORE_HPP_
 
@@ -12,13 +14,13 @@
 
 namespace NetworKit {
 
-class ChibaNishizekiQuadrangleEdgeScore : public EdgeScore<count> {
+class ChibaNishizekiQuadrangleEdgeScore final : public EdgeScore<count> {
 
 public:
-    ChibaNishizekiQuadrangleEdgeScore(const Graph& G);
-    virtual count score(edgeid eid) override;
-    virtual count score(node u, node v) override;
-    virtual void run() override;
+    ChibaNishizekiQuadrangleEdgeScore(const Graph &G);
+    count score(edgeid eid) override;
+    count score(node u, node v) override;
+    void run() override;
 };
 
 } // namespace NetworKit
