@@ -1,31 +1,33 @@
 /*
- * ChibaNishizekiTriangleEdgeScore.h
+ * ChibaNishizekiTriangleEdgeScore.hpp
  *
  *  Created on: 22.05.2014
  *      Author: Gerd Lindner
  */
 
+// networkit-format
+
 #ifndef NETWORKIT_EDGESCORES_CHIBA_NISHIZEKI_TRIANGLE_EDGE_SCORE_HPP_
 #define NETWORKIT_EDGESCORES_CHIBA_NISHIZEKI_TRIANGLE_EDGE_SCORE_HPP_
 
-#include <networkit/graph/Graph.hpp>
 #include <networkit/edgescores/EdgeScore.hpp>
+#include <networkit/graph/Graph.hpp>
 
 namespace NetworKit {
 
 /**
  * An implementation of the triangle counting algorithm by Chiba/Nishizeki.
  *
- * @deprecated Use TriangleEdgeScore instead which is parallelized and has a similar performance even in the sequential case.
+ * @deprecated Use TriangleEdgeScore instead which is parallelized and has a similar performance
+ * even in the sequential case.
  */
-class ChibaNishizekiTriangleEdgeScore : public EdgeScore<count> {
+class ChibaNishizekiTriangleEdgeScore final : public EdgeScore<count> {
 
 public:
-
-    ChibaNishizekiTriangleEdgeScore(const Graph& G);
-    virtual count score(edgeid eid) override;
-    virtual count score(node u, node v) override;
-    virtual void run() override;
+    ChibaNishizekiTriangleEdgeScore(const Graph &G);
+    count score(edgeid eid) override;
+    count score(node u, node v) override;
+    void run() override;
 };
 
 } /* namespace NetworKit */
