@@ -6,17 +6,17 @@
 namespace NetworKit {
 
 template <typename AttributeT>
-class PrefixJaccardScore : public EdgeScore<double> {
+class PrefixJaccardScore final : public EdgeScore<double> {
 
 public:
     PrefixJaccardScore(const Graph& G, const std::vector<AttributeT>& attribute);
-    virtual double score(edgeid eid) override;
-    virtual double score(node u, node v) override;
-    virtual void run() override;
+    double score(edgeid eid) override;
+    double score(node u, node v) override;
+    void run() override;
 
 
 private:
-    const std::vector<AttributeT>& inAttribute;
+    const std::vector<AttributeT>* inAttribute;
 
 };
 
