@@ -1,5 +1,5 @@
 /*
- * DynamicDorogovtsevMendesGenerator.h
+ * DynamicDorogovtsevMendesGenerator.hpp
  *
  *  Created on: 03.02.2014
  *      Author: cls
@@ -8,15 +8,15 @@
 #ifndef NETWORKIT_GENERATORS_DYNAMIC_DOROGOVTSEV_MENDES_GENERATOR_HPP_
 #define NETWORKIT_GENERATORS_DYNAMIC_DOROGOVTSEV_MENDES_GENERATOR_HPP_
 
-#include <networkit/generators/DynamicGraphGenerator.hpp>
 #include <networkit/auxiliary/Random.hpp>
+#include <networkit/generators/DynamicGraphGenerator.hpp>
 
 namespace NetworKit {
 
 /**
  * @ingroup generators
  */
-class DynamicDorogovtsevMendesGenerator: public DynamicGraphGenerator {
+class DynamicDorogovtsevMendesGenerator final: public DynamicGraphGenerator {
 
 public:
 
@@ -26,7 +26,7 @@ public:
 
 private:
 
-    std::vector<std::pair<node, node> > edges;
+    std::vector<std::pair<node, node>> edges;
     bool initial;
     node u; // current node
 
