@@ -1,17 +1,18 @@
 /*
- * QuadNode.h
+ * QuadNode.hpp
  *
  *  Created on: 21.05.2014
- *      Author: Moritz v. Looz (moritz.looz-corswarem@kit.edu)
+ *      Author: Moritz v. Looz
  */
 
 #ifndef NETWORKIT_GENERATORS_QUADTREE_QUAD_NODE_HPP_
 #define NETWORKIT_GENERATORS_QUADTREE_QUAD_NODE_HPP_
 
-#include <vector>
 #include <algorithm>
+#include <cassert>
 #include <functional>
-#include <assert.h>
+#include <vector>
+
 #include <networkit/auxiliary/Log.hpp>
 #include <networkit/auxiliary/Parallel.hpp>
 #include <networkit/geometric/HyperbolicSpace.hpp>
@@ -24,19 +25,19 @@ using std::cos;
 namespace NetworKit {
 
 template <class T, bool poincare = true>
-class QuadNode {
+class QuadNode final {
     friend class QuadTreeGTest;
-private:
+
     double leftAngle;
     double minR;
     double rightAngle;
     double maxR;
     Point2DWithIndex<double> a,b,c,d;
     unsigned capacity;
-    static const unsigned coarsenLimit = 4;
+    static constexpr unsigned coarsenLimit = 4;
     count subTreeSize;
     std::vector<T> content;
-    std::vector<Point2DWithIndex<double> > positions;
+    std::vector<Point2DWithIndex<double>> positions;
     std::vector<double> angles;
     std::vector<double> radii;
     bool isLeaf;
@@ -68,7 +69,6 @@ public:
     /**
      * Construct a QuadNode for polar coordinates.
      *
-     *
      * @param leftAngle Minimal angular coordinate of region, in radians from 0 to 2\pi
      * @param minR Minimal radial coordinate of region, between 0 and 1
      * @param rightAngle Maximal angular coordinate of region, in radians from 0 to 2\pi
@@ -127,8 +127,6 @@ public:
             middleR = acosh((1-balance)*cosh(alpha*maxR) + balance*cosh(alpha*minR))/alpha;
         }
 
-        //one could also use the median here. Results in worse asymptotical complexity, but maybe better runtime?
-
         assert(middleR < maxR);
         assert(middleR > minR);
 
@@ -256,7 +254,6 @@ public:
         }
     }
 
-
     /**
      * Check whether the region managed by this node lies outside of an Euclidean circle.
      *
@@ -323,7 +320,6 @@ public:
         return outOfReach(query, radius);
     }
 
-
     /**
      * @param phi Angular coordinate of query point
      * @param r_h radial coordinate of query point in poincare disk
@@ -636,7 +632,6 @@ public:
                 }
             }
         }
-        //DEBUG("Expected at most ", expectedNeighbours, " neighbours, got ", result.size() - offset);
         return candidatesTested;
     }
 
