@@ -1,9 +1,10 @@
 /*
- * Graph.h
+ * Graph.hpp
  *
  *  Created on: 01.06.2014
- *      Author: Christian Staudt (christian.staudt@kit.edu), Klara Reichard
- * (klara.reichard@gmail.com), Marvin Ritter (marvin.ritter@gmail.com)
+ *      Author: Christian Staudt
+ *              Klara Reichard <klara.reichard@gmail.com>
+ *              Marvin Ritter <marvin.ritter@gmail.com>
  */
 
 // networkit-format
@@ -91,7 +92,6 @@ class Graph final {
     friend class GraphBuilder;
     friend class CurveballDetails::CurveballMaterialization;
 
-private:
     // graph attributes
     //!< unique graph id, starts at 0
     count id;
@@ -907,9 +907,7 @@ public:
 
         bool operator!=(const NeighborWeightIterator &rhs) const { return !(*this == rhs); }
 
-        const std::pair<node, edgeweight> operator*() const {
-            return std::make_pair(*nIter, *wIter);
-        }
+        std::pair<node, edgeweight> operator*() const { return std::make_pair(*nIter, *wIter); }
     };
 
     /**
@@ -1578,7 +1576,7 @@ public:
      * @return a pair (n, m) where n is the number of nodes and m is the
      * number of edges
      */
-    std::pair<count, count> const TLX_DEPRECATED(size() const noexcept);
+    std::pair<count, count> TLX_DEPRECATED(size() const noexcept);
 
     /**
      * @return the density of the graph
@@ -1769,25 +1767,7 @@ public:
     }
 
     /**
-     * Get i-th (outgoing) neighbor of @a u.
-     * WARNING: This function is deprecated or only temporary.
-     *
-     * @param u Node.
-     * @param i index; should be in [0, degreeOut(u))
-     * @return @a i -th (outgoing) neighbor of @a u, or @c none if no such
-     * neighbor exists.
-     */
-    template <bool graphIsDirected>
-    node getIthNeighbor(node u, index i) const {
-        node v = outEdges[u][i];
-        if (useEdgeInIteration<graphIsDirected>(u, v))
-            return v;
-        else
-            return none;
-    }
-
-    /**
-     * Get i-th (outgoing) neighbor of @a u.
+     * Return the i-th (outgoing) neighbor of @a u.
      *
      * @param u Node.
      * @param i index; should be in [0, degreeOut(u))
@@ -1800,6 +1780,21 @@ public:
         return outEdges[u][i];
     }
 
+    /**
+     * Get i-th (outgoing) neighbor of @a u and the corresponding edge id.
+     *
+     * @param u Node.
+     * @param i index; should be in [0, degreeOut(u))
+     * @return pair: i-th (outgoing) neighbor of @a u and the corresponding
+     * edge id, or @c none if no such neighbor exists.
+     */
+    std::pair<node, edgeid> getIthNeighborWithId(node u, index i) const {
+        assert(hasEdgeIds());
+        if (!hasNode(u) || i >= outEdges[u].size())
+            return {none, none};
+        return {outEdges[u][i], outEdgeIds[u][i]};
+    }
+
     /* Derivative Graphs */
 
     /**
