@@ -1,8 +1,10 @@
+// networkit-format
+
 #ifndef NETWORKIT_IO_COVER_WRITER_HPP_
 #define NETWORKIT_IO_COVER_WRITER_HPP_
 
-#include <networkit/structures/Cover.hpp>
 #include <networkit/graph/Graph.hpp>
+#include <networkit/structures/Cover.hpp>
 
 namespace NetworKit {
 
@@ -11,12 +13,10 @@ namespace NetworKit {
  * Write a clustering to a file.
  */
 
-class CoverWriter
-{
-    public:
-
-        virtual void write(Cover& zeta, const std::string& path) const;
+class CoverWriter final {
+public:
+    void write(Cover &zeta, const std::string &path) const;
 };
-}
+} // namespace NetworKit
 
 #endif // NETWORKIT_IO_COVER_WRITER_HPP_
