@@ -1,10 +1,11 @@
-
 /*
- * ThrillGraphBinaryReader.h
+ * ThrillGraphBinaryReader.hpp
  *
- * @author Michael Hamann <michael.hamann@kit.edu>
+ * @author Michael Hamann
  */
 
+// networkit-format
+
 #ifndef NETWORKIT_IO_THRILL_GRAPH_BINARY_READER_HPP_
 #define NETWORKIT_IO_THRILL_GRAPH_BINARY_READER_HPP_
 
@@ -18,10 +19,9 @@ namespace NetworKit {
 /**
  * Reads a graph format consisting of a serialized DIA of vector<uint32_t> from thrill.
  */
-class ThrillGraphBinaryReader: public GraphReader {
+class ThrillGraphBinaryReader final : public GraphReader {
 
 public:
-
     /**
      * When the number of nodes is given, reading the graph is more efficient.
      *
@@ -32,10 +32,12 @@ public:
     /**
      * Given the path of an input file, read the graph contained.
      *
-     * @param[in]	path	input file path
+     * @param[in]  path  input file path
      */
-    Graph read(const std::string& path) override;
-    Graph read(const std::vector<std::string>& path);
+    Graph read(const std::string &path) override;
+
+    Graph read(const std::vector<std::string> &path);
+
 private:
     const count n;
 };
