@@ -1,8 +1,8 @@
 /*
- * AdjustedRandIndex.h
+ * AdjustedRandIndex.hpp
  *
  *  Created on: 11.04.2015
- *      Author: Kolja Esders (kolja.esders@student.kit.edu)
+ *      Author: Kolja Esders
  */
 
 #ifndef NETWORKIT_LINKPREDICTION_ADJUSTED_RAND_INDEX_HPP_
@@ -18,8 +18,7 @@ namespace NetworKit {
  * AdjustedRandIndex proposed by Hoffman et al. with natural threshold of 0.
  * See http://www.sciencedirect.com/science/article/pii/S0378873315000210 for details.
  */
-class AdjustedRandIndex : public LinkPredictor {
-private:
+class AdjustedRandIndex final : public LinkPredictor {
   /**
    * Returns the Adjusted Rand Index of the given node-pair (@a u, @a v).
    * @param u First node
