@@ -1,5 +1,5 @@
 /*
- * NeighborhoodDistanceIndex.h
+ * NeighborhoodDistanceIndex.hpp
  *
  *  Created on: 24.06.2013
  *      Authors: cls, Kolja Esders
@@ -8,9 +8,9 @@
 #ifndef NETWORKIT_LINKPREDICTION_NEIGHBORHOOD_DISTANCE_INDEX_HPP_
 #define NETWORKIT_LINKPREDICTION_NEIGHBORHOOD_DISTANCE_INDEX_HPP_
 
-#include <networkit/linkprediction/LinkPredictor.hpp>
 #include <math.h>
-#include <algorithm>
+
+#include <networkit/linkprediction/LinkPredictor.hpp>
 
 namespace NetworKit {
 
@@ -20,19 +20,23 @@ namespace NetworKit {
  * Assigns a distance value to pairs of nodes according to the
  * overlap of their neighborhoods.
  */
-class NeighborhoodDistanceIndex : public LinkPredictor {
-private:
+class NeighborhoodDistanceIndex final : public LinkPredictor {
   /**
    * Returns the Neighborhood Distance index for the given node-pair (@a u, @a v).
    * @param u First node
    * @param v Second node
    * @return the Neighborhood Distance index for the given node-pair (@a u, @a v)
    */
-  virtual double runImpl(node u, node v) override;
+  double runImpl(node u, node v) override {
+    count uNeighborhood = G->degree(u);
+    count vNeighborhood = G->degree(v);
+    count intersection = NeighborhoodUtility::getCommonNeighbors(*G, u, v).size();
+    return ((double)intersection) / (sqrt(uNeighborhood * vNeighborhood));
+  }
 
 public:
   using LinkPredictor::LinkPredictor;
-  
+
 };
 
 } /* namespace NetworKit */
