@@ -1,8 +1,8 @@
 /*
- * PreferentialAttachmentIndex.h
+ * PreferentialAttachmentIndex.hpp
  *
  *  Created on: 22.03.2015
- *      Author: Kolja Esders (kolja.esders@student.kit.edu)
+ *      Author: Kolja Esders
  */
 
 #ifndef NETWORKIT_LINKPREDICTION_PREFERENTIAL_ATTACHMENT_INDEX_HPP_
@@ -15,19 +15,20 @@ namespace NetworKit {
 /**
  * @ingroup linkprediction
  *
- * Implementation of the Preferential Attachment Index. 
+ * Implementation of the Preferential Attachment Index.
  * The run-method simply calculates the product of the number of nodes in the neighborhoods
  * regarding the given nodes.
  */
-class PreferentialAttachmentIndex : public LinkPredictor {
-private:
+class PreferentialAttachmentIndex final : public LinkPredictor {
   /**
    * Returns the product of the cardinalities of the neighborhoods regarding @a u and @a v.
    * @param u First node
    * @param v Second node
    * @return the product of the cardinalities of the neighborhoods regarding @a u and @a v
    */
-  double runImpl(node u, node v) override;
+  double runImpl(node u, node v) override {
+    return G->degree(u) * G->degree(v);
+  }
 
 public:
   using LinkPredictor::LinkPredictor;
