@@ -1,8 +1,8 @@
 /*
- * VDegreeIndex.h
+ * VDegreeIndex.hpp
  *
  *  Created on: 01.04.2015
- *      Author: Kolja Esders (kolja.esders@student.kit.edu)
+ *      Author: Kolja Esders
  */
 
 #ifndef NETWORKIT_LINKPREDICTION_V_DEGREE_INDEX_HPP_
@@ -17,19 +17,20 @@ namespace NetworKit {
  *
  * Index that simply returns the degree of the second given node.
  */
-class VDegreeIndex : public LinkPredictor {
-private:
+class VDegreeIndex final : public LinkPredictor {
   /**
    * Returns the degree of the second node provided, namely @a v.
    * @param u First node
    * @param v Second node
    * @return the degree of the second node provided, namely @a v
    */
-  double runImpl(node u, node v) override;
+  double runImpl(node, node v) override {
+    return G->degree(v);
+  }
 
 public:
   using LinkPredictor::LinkPredictor;
-  
+
 };
 
 } // namespace NetworKit
