@@ -1,16 +1,15 @@
 /*
- * Matcher.h
+ * Matcher.hpp
  *
  *  Created on: 30.10.2012
- *      Author: Christian Staudt (christian.staudt@kit.edu)
+ *      Author: Christian Staudt
  */
 
 #ifndef NETWORKIT_MATCHING_MATCHER_HPP_
 #define NETWORKIT_MATCHING_MATCHER_HPP_
 
-#include <networkit/matching/Matching.hpp>
 #include <networkit/base/Algorithm.hpp>
-
+#include <networkit/matching/Matching.hpp>
 
 namespace NetworKit {
 
@@ -20,10 +19,10 @@ namespace NetworKit {
  */
 class Matcher : public Algorithm {
 protected:
-    const Graph& G;
+    const Graph* G;
     Matching M;
-    bool edgeScoresAsWeights;	//<! if true, algorithm should use edge scores instead of edge weights
-    const std::vector<double> edgeScores; 	//<! optional edge scores to be used instead of edge weight
+    bool edgeScoresAsWeights;  //<! if true, algorithm should use edge scores instead of edge weights
+    const std::vector<double> edgeScores;   //<! optional edge scores to be used instead of edge weight
 
 public:
     /**
@@ -40,15 +39,13 @@ public:
     Matcher(const Graph& G, const std::vector<double>& edgeScores);
 
     /** Default destructor */
-    virtual ~Matcher() = default;
-
+    ~Matcher() override = default;
 
     /**
      * Run the matching algorithm on the stored graph and return a matching.
      * @return A matching of the stored graph.
      */
-    virtual void run() = 0;
-
+    void run() override = 0;
 
     Matching getMatching() const;
 };
