@@ -1,5 +1,5 @@
 /*
- * PathGrowingMatcher.h
+ * PathGrowingMatcher.hpp
  *
  *  Created on: Jun 13, 2013
  *      Author: Henning
@@ -16,11 +16,11 @@ namespace NetworKit {
 /**
  * @ingroup matching
  * Path growing matching algorithm as described by
- *   Hougardy and Drake, http://dx.doi.org/10.1016/S0020-0190(02)00393-9
+ * Hougardy and Drake, http://dx.doi.org/10.1016/S0020-0190(02)00393-9
  * Computes an approximate maximum weight matching with guarantee 1/2.
  * (Note that better algorithms in terms of approximation quality exist.)
  */
-class PathGrowingMatcher: public Matcher {
+class PathGrowingMatcher final: public Matcher {
 public:
     /**
      * @param[in] G Graph for which matching is computed.
@@ -37,7 +37,7 @@ public:
      * for graph @a G.
      * @return Matching (at least half as heavy as maximum weight matching).
      */
-    virtual void run();
+    void run() override;
 };
 
 } /* namespace NetworKit */
