@@ -1,5 +1,5 @@
 /*
- * SimmelianOverlapScore.h
+ * SimmelianOverlapScore.hpp
  *
  *  Created on: 22.07.2014
  *      Author: Gerd Lindner
@@ -16,16 +16,16 @@ namespace NetworKit {
 /**
  * Calculates the Simmelian backbone (paramaetric variant) for a given input graph.
  */
-class SimmelianOverlapScore : public SimmelianScore {
+class SimmelianOverlapScore final : public SimmelianScore {
 
 public:
 
     /**
      * Creates a new instance of the parametric variant of the Simmelian Backbone calculator.
-     * @param maxRank 		the maximum rank that is considered for overlap calculation
+     * @param maxRank     the maximum rank that is considered for overlap calculation
      */
     SimmelianOverlapScore(const Graph& graph, const std::vector<count>& triangles, count maxRank);
-    virtual void run() override;
+    void run() override;
 
 private:
     count maxRank;
