@@ -6,15 +6,18 @@ __author__ = "Christian Staudt"
 __credits__ = ["Christian Staudt", "Elisabetta Bergamini", "Henning Meyerhenke", "Marc Nemes", "Maximilian Vogel"]
 
 # extension imports
-# TODO: (+) ApproxCloseness
 
 from _NetworKit import Betweenness, PageRank, EigenvectorCentrality, DegreeCentrality, ApproxBetweenness,\
 ApproxBetweenness2, EstimateBetweenness, DynApproxBetweenness, Closeness, HarmonicCloseness, KPathCentrality, CoreDecomposition,\
 KatzCentrality, LocalClusteringCoefficient, ApproxCloseness, LocalPartitionCoverage, Sfigality, SpanningEdgeCentrality,\
 PermanenceCentrality, TopCloseness, TopHarmonicCloseness, DynTopHarmonicCloseness, DynBetweenness,\
 GroupDegree, GroupCloseness, DynBetweennessOneNode, LaplacianCentrality, ApproxGroupBetweenness, DynKatzCentrality,\
-KadabraBetweenness
+KadabraBetweenness, ApproxSpanningEdge, GedWalk
+
 from _NetworKit import _ClosenessVariant as ClosenessVariant
+from _NetworKit import _PageRankNorm as Norm
+from _NetworKit import _BoundStrategy as BoundStrategy
+from _NetworKit import _GreedyStrategy as GreedyStrategy
 
 # local imports
 from networkit.algebraic import adjacencyEigenvector, PageRankMatrix, symmetricEigenvectors
