@@ -5,8 +5,9 @@
  *      Author: cls
  */
 
-#include "Centrality.h"
-#include "../auxiliary/Parallel.h"
+#include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/auxiliary/Log.hpp>
+#include <networkit/centrality/Centrality.hpp>
 
 namespace NetworKit {
 
@@ -45,6 +46,11 @@ std::vector<double> Centrality::scores(bool moveOut) {
   return moveOut ? std::move(scoreData) : scoreData;
 }
 
+const std::vector<double> &Centrality::scores() const {
+  assureFinished();
+  return scoreData;
+}
+
 std::vector<double> Centrality::edgeScores() {
   assureFinished();
   return edgeScoreData;
