@@ -14,6 +14,7 @@
 #include <networkit/auxiliary/Timer.hpp>
 #include <networkit/centrality/ApproxBetweenness.hpp>
 #include <networkit/centrality/ApproxCloseness.hpp>
+#include <networkit/centrality/ApproxSpanningEdge.hpp>
 #include <networkit/centrality/ApproxGroupBetweenness.hpp>
 #include <networkit/centrality/Betweenness.hpp>
 #include <networkit/centrality/Closeness.hpp>
@@ -23,6 +24,7 @@
 #include <networkit/centrality/DynTopHarmonicCloseness.hpp>
 #include <networkit/centrality/EigenvectorCentrality.hpp>
 #include <networkit/centrality/EstimateBetweenness.hpp>
+#include <networkit/centrality/GedWalk.hpp>
 #include <networkit/centrality/GroupCloseness.hpp>
 #include <networkit/centrality/GroupDegree.hpp>
 #include <networkit/centrality/HarmonicCloseness.hpp>
@@ -480,20 +482,33 @@ TEST_F(CentralityGTest, testKatzDirectedDeletion) {
     INFO("Level reached: ", kc.levelReached, ", ", kc2.levelReached);
 }
 
-// TODO: replace by smaller graph
-TEST_F(CentralityGTest, testPageRankDirected) {
-    SNAPGraphReader reader;
-    Graph G = reader.read("input/wiki-Vote.txt");
-    PageRank pr(G);
+TEST_P(CentralityGTest, testPageRank) {
+    SNAPGraphReader reader(isDirected());
+    auto G = reader.read("input/wiki-Vote.txt");
 
-    DEBUG("start pr run");
-    pr.run();
-    DEBUG("finish pr");
-    std::vector<std::pair<node, double>> pr_ranking = pr.ranking();
+    auto doTest = [&G](PageRank::Norm norm) {
+        PageRank pr(G);
+        pr.norm = norm;
+        pr.run();
 
-    const double tol = 1e-3;
-    EXPECT_EQ(pr_ranking[0].first, 699);
-    EXPECT_NEAR(pr_ranking[0].second, 0.00432, tol);
+        auto pr_ranking = pr.ranking();
+        constexpr double eps = 1e-3;
+        if (G.isDirected()) {
+            EXPECT_EQ(pr_ranking[0].first, 326);
+            EXPECT_NEAR(pr_ranking[0].second, 0.00460, eps);
+        } else {
+            EXPECT_EQ(pr_ranking[0].first, 699);
+            EXPECT_NEAR(pr_ranking[0].second, 0.00432, eps);
+        }
+
+        constexpr count maxIterations = 2;
+        pr.maxIterations = maxIterations;
+        pr.run();
+        EXPECT_LE(pr.numberOfIterations(), maxIterations);
+    };
+
+    doTest(PageRank::Norm::L1Norm);
+    doTest(PageRank::Norm::L2Norm);
 }
 
 TEST_F(CentralityGTest, testEigenvectorCentrality) {
@@ -1206,6 +1221,7 @@ TEST_P(CentralityGTest, testTopCloseness) {
 TEST_F(CentralityGTest, testTopHarmonicClosenessDirected) {
     count size = 400;
     count k = 10;
+    Aux::Random::setSeed(42, false);
     Graph G1 = DorogovtsevMendesGenerator(size).generate();
     Graph G(G1.upperNodeIdBound(), false, true);
     G1.forEdges([&](node u, node v) {
@@ -1721,4 +1737,70 @@ TEST_P(CentralityGTest, testDynTopHarmonicCloseness) {
     }
 }
 
+TEST_F(CentralityGTest, testApproxSpanningEdge) {
+    Aux::Random::setSeed(42, false);
+
+    // Testing a graph that is too small yields approximation errors; however, if the input
+    // graph has > 100 nodes, running the exact algorithm takes too long.
+    // Therefore, in this test we use the approximation algorithm implemented in
+    // SpanningEdgeCentrality as baseline, and check that the values are within a 2-epsilon
+    // approximation.
+    Graph G = ErdosRenyiGenerator(300, 0.1, false).generate();
+    G.indexEdges();
+    constexpr double eps = 0.1;
+
+    ApproxSpanningEdge apx(G, eps);
+    apx.run();
+    SpanningEdgeCentrality se(G, eps);
+    se.runParallelApproximation();
+    auto apxScores = apx.scores();
+    auto exactScores = se.scores();
+
+    G.forEdges([&](node /*u*/, node /*v*/, edgeweight /*w*/, edgeid eid) {
+        EXPECT_NEAR(apxScores[eid], exactScores[eid], 2*eps);
+    });
+}
+
+TEST_P(CentralityGTest, testGedWalk) {
+    Aux::Random::setSeed(42, true);
+    constexpr count k = 3;
+    constexpr double epsilon = 0.01;
+    auto g = ErdosRenyiGenerator(20, 0.1, isDirected()).generate();
+
+    for (const auto bs : {GedWalk::BoundStrategy::geometric, GedWalk::BoundStrategy::spectral}) {
+        for (const auto gs : {GedWalk::GreedyStrategy::lazy, GedWalk::GreedyStrategy::stochastic}) {
+            GedWalk gedWalk(g, k, epsilon, -1.0, bs, gs);
+            gedWalk.run();
+
+            const auto apxScore = gedWalk.getApproximateScore();
+            EXPECT_GE(apxScore, 0);
+            const auto apxGroup = gedWalk.groupMaxGedWalk();
+            EXPECT_EQ(std::unordered_set<node>(apxGroup.begin(), apxGroup.end()).size(), k);
+
+            double maxScore = 0.;
+            std::vector<node> group;
+            std::vector<node> max_group;
+            std::vector<bool> reference(g.numberOfNodes(), false);
+            std::fill(reference.end() - k, reference.end(), true);
+
+            do {
+                group.clear();
+                for (count i = 0; i < reference.size(); ++i) {
+                    if (reference[i]) {
+                        group.push_back(i);
+                    }
+                }
+
+                const auto curScore = gedWalk.scoreOfGroup(group.begin(), group.end(), epsilon);
+                if (curScore > maxScore) {
+                    maxScore = curScore;
+                    max_group = group;
+                }
+            } while (std::next_permutation(reference.begin(), reference.end()));
+
+            EXPECT_GE(apxScore, (1. - 1. / std::exp(1)) * maxScore - epsilon);
+        }
+    }
+}
+
 } /* namespace NetworKit */
