@@ -1,30 +1,27 @@
-/*
- *
- */
-
-#include <networkit/community/PartitionHubDominance.hpp>
-#include <networkit/auxiliary/SignalHandling.hpp>
-#include <networkit/auxiliary/Parallel.hpp>
 #include <atomic>
 #include <memory>
 
+#include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/auxiliary/SignalHandling.hpp>
+#include <networkit/community/PartitionHubDominance.hpp>
+
 void NetworKit::PartitionHubDominance::run() {
     hasRun = false;
 
     Aux::SignalHandler handler;
 
-    std::unique_ptr<std::atomic<count>[]> maxInternalDeg(new std::atomic<count>[P.upperBound()]{});
-    std::vector<count> clusterSizes(P.upperBound(), 0);
+    std::unique_ptr<std::atomic<count>[]> maxInternalDeg(new std::atomic<count>[P->upperBound()]{});
+    std::vector<count> clusterSizes(P->upperBound(), 0);
 
     handler.assureRunning();
 
-    G.balancedParallelForNodes([&](node u) {
-        index c = P[u];
+    G->balancedParallelForNodes([&](node u) {
+        index c = (*P)[u];
 
         if (c != none) {
             count internalDeg = 0;
-            G.forNeighborsOf(u, [&](node v) {
-                if (P[v] == c) {
+            G->forNeighborsOf(u, [&](node v) {
+                if ((*P)[v] == c) {
                     internalDeg++;
                 }
             });
@@ -44,9 +41,9 @@ void NetworKit::PartitionHubDominance::run() {
     maximumValue = std::numeric_limits<double>::lowest();
     minimumValue = std::numeric_limits<double>::max();
     values.clear();
-    values.resize(P.upperBound(), 0);
+    values.resize(P->upperBound(), 0);
 
-    for (index i = 0; i < P.upperBound(); ++i) {
+    for (index i = 0; i < P->upperBound(); ++i) {
         if (clusterSizes[i] > 0) {
             ++numClusters;
 
@@ -67,6 +64,6 @@ void NetworKit::PartitionHubDominance::run() {
     handler.assureRunning();
 
     unweightedAverage /= numClusters;
-    weightedAverage /= G.numberOfNodes();
+    weightedAverage /= G->numberOfNodes();
     hasRun = true;
 }
