@@ -1,32 +1,29 @@
-/*
- *
- */
-
-#include <networkit/community/StablePartitionNodes.hpp>
-#include <networkit/auxiliary/SignalHandling.hpp>
 #include <limits>
 #include <map>
 
+#include <networkit/auxiliary/SignalHandling.hpp>
+#include <networkit/community/StablePartitionNodes.hpp>
+
 void NetworKit::StablePartitionNodes::run() {
     hasRun = false;
 
     Aux::SignalHandler handler;
 
     stableMarker.clear();
-    stableMarker.resize(G.upperNodeIdBound(), true);
+    stableMarker.resize(G->upperNodeIdBound(), true);
     values.clear();
 
     handler.assureRunning();
 
     // first determine which nodes are stable
-    G.balancedParallelForNodes([&](node u) {
-        if (G.degree(u) > 0) { // we consider isolated nodes to be stable.
+    G->balancedParallelForNodes([&](node u) {
+        if (G->degree(u) > 0) { // we consider isolated nodes to be stable.
             std::map<index, count> labelWeights;
-            G.forNeighborsOf(u, [&](node v, edgeweight ew) {
-                labelWeights[P[v]] += ew;
+            G->forNeighborsOf(u, [&](node v, edgeweight ew) {
+                labelWeights[(*P)[v]] += ew;
             });
 
-            index ownLabel = P[u];
+            index ownLabel = (*P)[u];
             double ownWeight = labelWeights[ownLabel];
 
             if (ownWeight == 0) {
@@ -44,14 +41,14 @@ void NetworKit::StablePartitionNodes::run() {
 
     handler.assureRunning();
 
-    values.resize(P.upperBound(), 0);
-    std::vector<count> partitionSizes(P.upperBound(), 0);
+    values.resize(P->upperBound(), 0);
+    std::vector<count> partitionSizes(P->upperBound(), 0);
     count stableCount = 0;
 
     // collect how many nodes are stable in which partition
-    G.forNodes([&](node u) {
-        ++partitionSizes[P[u]];
-        values[P[u]] += stableMarker[u];
+    G->forNodes([&](node u) {
+        ++partitionSizes[(*P)[u]];
+        values[(*P)[u]] += stableMarker[u];
         stableCount += stableMarker[u];
     });
 
@@ -61,7 +58,7 @@ void NetworKit::StablePartitionNodes::run() {
     maximumValue = std::numeric_limits<double>::lowest();
 
     // calculate all average/max/min-values
-    for (index i = 0; i < P.upperBound(); ++i) {
+    for (index i = 0; i < P->upperBound(); ++i) {
         if (partitionSizes[i] > 0) {
             values[i] /= partitionSizes[i];
             unweightedAverage += values[i];
@@ -72,7 +69,7 @@ void NetworKit::StablePartitionNodes::run() {
     }
 
     unweightedAverage /= numClusters;
-    weightedAverage = stableCount * 1.0 / G.numberOfNodes();
+    weightedAverage = stableCount * 1.0 / G->numberOfNodes();
 
     handler.assureRunning(); // make sure we do not ignore the signal sent by the user
 
