@@ -14,23 +14,19 @@
 namespace NetworKit {
 
 RandomSpanningForest::RandomSpanningForest(const Graph& G):
-        SpanningForest(G)
-{
-
-}
+        SpanningForest(G) {}
 
 void RandomSpanningForest::run() {
     // handle disconnected graphs:
     // determine connected components first
     // then start random walk in each component!
-    ConnectedComponents cc(G);
+    ConnectedComponents cc(*G);
     cc.run();
-    std::vector<std::vector<node> > comps = cc.getComponents();
+    const auto comps = cc.getComponents();
 
-    forest = GraphTools::copyNodes(G);
-    for (auto comp: comps) {
+    forest = GraphTools::copyNodes(*G);
+    for (const auto &comp: comps) {
         std::unordered_set<node> visited;
-        const count compSize = comp.size();
 
         // find and process random root
         index rand = Aux::Random::integer(comp.size() - 1);
@@ -38,9 +34,9 @@ void RandomSpanningForest::run() {
         visited.insert(curr);
 
         // random walk starting from root
-        while (visited.size() < compSize) {
+        while (visited.size() < comp.size()) {
             // get random neighbor
-            node neigh = GraphTools::randomNeighbor(G, curr);
+            node neigh = GraphTools::randomNeighbor(*G, curr);
 
             // if not seen before, insert tree edge
             if (visited.count(neigh) == 0) {
