@@ -5,28 +5,28 @@
 *      Author: Maximilian Vogel
 */
 
-#include <networkit/distance/NeighborhoodFunctionApproximation.hpp>
-#include <networkit/components/ConnectedComponents.hpp>
-#include <networkit/auxiliary/Random.hpp>
-#include <networkit/Globals.hpp>
-
-#include <math.h>
-#include <iterator>
-#include <stdlib.h>
-#include <omp.h>
+#include <cmath>
 #include <map>
+#include <omp.h>
 #include <vector>
 
+#include <networkit/Globals.hpp>
+#include <networkit/auxiliary/Random.hpp>
+#include <networkit/components/ConnectedComponents.hpp>
+#include <networkit/distance/NeighborhoodFunctionApproximation.hpp>
+
 namespace NetworKit {
 
-NeighborhoodFunctionApproximation::NeighborhoodFunctionApproximation(const Graph& G, const count k, const count r) : Algorithm(), G(G), k(k), r(r), result() {
-    if (G.isDirected()) throw std::runtime_error("current implementation can only deal with undirected graphs");
+NeighborhoodFunctionApproximation::NeighborhoodFunctionApproximation(const Graph& G, const count k, const count r) : Algorithm(), G(&G), k(k), r(r), result() {
+    if (G.isDirected())
+        throw std::runtime_error("current implementation can only deal with undirected graphs");
     ConnectedComponents cc(G);
     cc.run();
-    if (cc.getPartition().numberOfSubsets() > 1) throw std::runtime_error("current implementation only runs on graphs with 1 connected component");
+    if (cc.numberOfComponents() > 1)
+        throw std::runtime_error("current implementation only runs on graphs with 1 connected component");
 }
 
-#ifdef _MSC_VER 
+#ifdef _MSC_VER
 // MSVC Optimizer crashes with an internal error message.
 // Until this is either fixed by Microsoft, or the issue here can was
 // found, let's just disable the optimizer.
@@ -34,22 +34,22 @@ NeighborhoodFunctionApproximation::NeighborhoodFunctionApproximation(const Graph
 #endif // _MSC_VER
 void NeighborhoodFunctionApproximation::run() {
     // the length of the bitmask where the number of connected nodes is saved
-    const count lengthOfBitmask = (count) ceil(log2(G.numberOfNodes())) + r;
+    const count lengthOfBitmask = (count) ceil(log2(G->numberOfNodes())) + r;
     // saves all k bitmasks for every node of the current iteration
-    std::vector<std::vector<unsigned int> > mCurr(G.upperNodeIdBound());
+    std::vector<std::vector<unsigned int>> mCurr(G->upperNodeIdBound());
     // saves all k bitmasks for every node of the previous iteration
-    std::vector<std::vector<unsigned int> > mPrev(G.upperNodeIdBound());
+    std::vector<std::vector<unsigned int>> mPrev(G->upperNodeIdBound());
     // the list of nodes that are already connected to all other nodes
     std::vector<unsigned int> highestCount(k, 0);
     // nodes that are not connected to enough nodes yet
-    std::vector<char> activeNodes(G.upperNodeIdBound(),0);
+    std::vector<char> activeNodes(G->upperNodeIdBound(),0);
 
     // initialize all vectors
     std::vector<std::vector<unsigned int>> localHighest(omp_get_max_threads(), std::vector<unsigned int>(k, 0));
 
     std::vector<unsigned int> bitmasks(k, 0);
     Aux::Random::setSeed(Aux::Random::getSeed(), true);
-    G.parallelForNodes([&](node v) {
+    G->parallelForNodes([&](node v) {
         mCurr[v] = bitmasks;
         mPrev[v] = bitmasks;
         activeNodes[v] = 1;
@@ -76,7 +76,7 @@ void NeighborhoodFunctionApproximation::run() {
 
     std::vector<count> localEstimatesSum(omp_get_max_threads(), 0);
     std::vector<count> localSumRemoved(omp_get_max_threads(), 0);
-    
+
     bool queued = true;
     while (queued) {
         queued = false;
@@ -84,14 +84,14 @@ void NeighborhoodFunctionApproximation::run() {
         for (index i = 0; i < (count)omp_get_max_threads(); ++i) {
             tmp += localSumRemoved[i];
         }
-        #pragma omp parallel for schedule(guided) 
+        #pragma omp parallel for schedule(guided)
         for (omp_index v = 0; v < static_cast<omp_index>(activeNodes.size()); ++v) {
             if (!activeNodes[v]) continue;
             index tid = (index)omp_get_thread_num();
-            
+
             for (count j = 0; j < k; j++) {
                 // and to all previous neighbors of all its neighbors
-                G.forNeighborsOf(v, [&](node u) {
+                G->forNeighborsOf(v, [&](node u) {
                     mCurr[v][j] |= mPrev[u][j];
                 });
             }
@@ -137,7 +137,7 @@ void NeighborhoodFunctionApproximation::run() {
     }
     hasRun = true;
 }
-#ifdef _MSC_VER 
+#ifdef _MSC_VER
 #pragma optimize( "", on)
 #endif // _MSC_VER
 
@@ -148,5 +148,4 @@ std::vector<count> NeighborhoodFunctionApproximation::getNeighborhoodFunction()
     return result;
 }
 
-
-}
+} // namespace NetworKit
