@@ -5,9 +5,11 @@
  *      Author: forigem
  */
 
-#include <networkit/generators/DynamicDGSParser.hpp>
+#include <fstream>
+
 #include <networkit/auxiliary/Log.hpp>
 #include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/generators/DynamicDGSParser.hpp>
 
 namespace NetworKit {
 
@@ -57,7 +59,6 @@ void DynamicDGSParser::generate() {
         std::vector<std::string> split = Aux::StringTools::split(line);
         std::string tag = split[0];
 
-        //std::unordered_map<std::string, node> edgeNames;
 
         if (tag.compare("st") == 0 && split.size() == 2) { // clock
             Gproxy->timeStep();
@@ -77,10 +78,7 @@ void DynamicDGSParser::generate() {
                 std::string categoriesCommaSeparated = categoriesFullStringSplit[1]; // Example: cond-mat.stat-mech, q-fin.ST
                 std::vector<std::string> categories = Aux::StringTools::split(categoriesCommaSeparated, ',');
 
-                std::vector<std::string> currentNodeCategories;
-                for (std::string category : categories) {
-                    currentNodeCategories.push_back(category);
-                }
+                std::vector<std::string> currentNodeCategories(categories.begin(), categories.end());
                 nodeCategories.push_back(currentNodeCategories);
                 assert(nodeCategories.size() > 0);
 
@@ -182,7 +180,7 @@ void DynamicDGSParser::evaluateClusterings(const std::string path, const Partiti
         std::vector<std::string> currentNodeCategories = nodeCategories[v];
         clusterMappings[normalizedID].reserve(100000);
 
-        for (std::string category : currentNodeCategories) {
+        for (const std::string &category : currentNodeCategories) {
             clusterMappings[normalizedID].find (category);
 
             std::unordered_map<std::string, index>::const_iterator got = clusterMappings[normalizedID].find (category);
@@ -204,11 +202,6 @@ void DynamicDGSParser::evaluateClusterings(const std::string path, const Partiti
         if (clusterSizes[i] >= 20) {
             fs << "cluster-" << i << '\t';
             fs << "size " << '\t' << clusterSizes[i] << '\t';
-            /* old output
-            for (const auto &pair : clusterMappings[i]) {
-                fs << pair.first << '\t' << pair.second << '\t';
-            }
-            */
             std::vector<count> vals;
             vals.reserve(clusterMappings.size());
 
