@@ -6,17 +6,16 @@
  *      Contributors: Hoske/Weisbarth
  */
 
-#include <networkit/generators/HavelHakimiGenerator.hpp>
-
 #include <list>
 #include <stack>
+
 #include <networkit/auxiliary/Log.hpp>
+#include <networkit/generators/HavelHakimiGenerator.hpp>
 
 namespace NetworKit {
 
 HavelHakimiGenerator::HavelHakimiGenerator(const std::vector<count> &sequence, bool ignoreIfRealizable) :
-        StaticDegreeSequenceGenerator(sequence), ignoreIfRealizable(ignoreIfRealizable) {
-}
+        StaticDegreeSequenceGenerator(sequence), ignoreIfRealizable(ignoreIfRealizable) {}
 
 
 Graph HavelHakimiGenerator::generate() {
@@ -42,9 +41,7 @@ Graph HavelHakimiGenerator::generate() {
     }
 
     index maxDeficit = numDegVals - 1;
-    while (maxDeficit > 0) {
-//		DEBUG("maxDeficit: ", maxDeficit);
-
+    while (maxDeficit) {
         // process node in largest bucket
         while(! nodesByDeficit[maxDeficit].empty()) {
             // get element
@@ -59,16 +56,13 @@ Graph HavelHakimiGenerator::generate() {
             index currentNeighborList = maxDeficit;
             std::stack<count> numToMove;
 
-            while (deficit > 0) {
-//				DEBUG("deficit: ", deficit);
-//				DEBUG("currentNeighborList: ", currentNeighborList);
+            while (deficit) {
                 count numDeleteFromCurrentList = 0;
 
                 // search for candidates in current list
                 for (auto elem : nodesByDeficit[currentNeighborList]) {
                     // connect
                     node nextNeighbor = elem.second;
-//						DEBUG("add edge ", currentVertex, "-", nextNeighbor);
                     G.addEdge(currentVertex, nextNeighbor);
 
                     --deficit;
@@ -108,7 +102,6 @@ Graph HavelHakimiGenerator::generate() {
 
                 ++currentNeighborList;
             }
-//			DEBUG("adapt nodes in set");
         }
         maxDeficit--;
     }
