@@ -1,10 +1,6 @@
-/*
- *
- */
-
 #include <algorithm>
-#include <random>
 #include <numeric>
+#include <random>
 
 #include <networkit/auxiliary/Log.hpp>
 #include <networkit/auxiliary/Random.hpp>
@@ -133,7 +129,7 @@ void NetworKit::LFRGenerator::setPartition(NetworKit::Partition zeta) {
 
 NetworKit::Graph NetworKit::LFRGenerator::generateIntraClusterGraph(std::vector< NetworKit::count > intraDegreeSequence, const std::vector<NetworKit::node> &localToGlobalNode) {
     // check if sum of degrees is even and fix if necessary
-    count intraDegSum = std::accumulate(intraDegreeSequence.begin(), intraDegreeSequence.end(), 0);
+    count intraDegSum = std::accumulate(intraDegreeSequence.begin(), intraDegreeSequence.end(), count{0});
 
     DEBUG("Possibly correcting the degree sequence");
 
@@ -555,6 +551,3 @@ std::string NetworKit::LFRGenerator::toString() const {
 bool NetworKit::LFRGenerator::isParallel() const {
     return false;
 }
-
-
-
