@@ -1,20 +1,29 @@
 /*
-* StochasticBlockmodel.h
+* StochasticBlockmodel.cpp
 *
 *  Created on: 13.08.2014
 *      Author: Christian Staudt
 */
 
-#include <networkit/generators/StochasticBlockmodel.hpp>
 #include <networkit/auxiliary/Random.hpp>
+#include <networkit/generators/StochasticBlockmodel.hpp>
 
 namespace NetworKit {
 
-StochasticBlockmodel::StochasticBlockmodel(count n, count nBlocks, const std::vector<index>& membership, const std::vector<std::vector<double> >& affinity)
-    : n(n), nBlocks(nBlocks), membership(membership), affinity(affinity) {
+StochasticBlockmodel::StochasticBlockmodel(count n, count nBlocks, const std::vector<index>& membership, const std::vector<std::vector<double>>& affinity)
+    : n(n), membership(membership), affinity(affinity) {
+
+    std::string errorMessage = "affinity matrix must be of size nBlocks x nBlocks";
     if (affinity.size() != nBlocks) {
-        throw std::runtime_error("affinity matrix must be of size nBlocks x nBlocks");
+        throw std::runtime_error(errorMessage);
     }
+
+    for (const auto &row : affinity) {
+        if (row.size() != nBlocks) {
+            throw std::runtime_error(errorMessage);
+        }
+    }
+
     if (membership.size() != n) {
         throw std::runtime_error("membership list must be of size nNodes");
     }
@@ -27,8 +36,8 @@ Graph StochasticBlockmodel::generate() {
     G.forNodePairs([&](node u, node v) {
         index a = membership.at(u);
         index b = membership.at(v);
-        assert (a < nBlocks);
-        assert (b < nBlocks);
+        assert (a < affinity.size());
+        assert (b < affinity.size());
         double p = affinity.at(a).at(b);
         double r = Aux::Random::real();
         if (r <= p) {
