@@ -37,7 +37,7 @@ Graph WattsStrogatzGenerator::generate() {
     auto validEndNode = [&G](const node u, const node v) { return u != v && !G.hasEdge(u, v); };
 
     std::vector<node> prevNeighbors;
-    prevNeighbors.reserve(GraphTools::maxDegree(G));
+    prevNeighbors.resize(GraphTools::maxDegree(G));
 
     // rewire according to Watts and Strogatz model
     for (const auto u : G.nodeRange()) {
