@@ -7,9 +7,12 @@
 
 #include <iostream>
 #include <map>
+#include <unordered_map>
 
-#include <networkit/io/DGSReader.hpp>
 #include <networkit/auxiliary/Log.hpp>
+#include <networkit/auxiliary/StringTools.hpp>
+#include <networkit/dynamics/GraphEventProxy.hpp>
+#include <networkit/io/DGSReader.hpp>
 
 namespace NetworKit {
 
@@ -47,8 +50,6 @@ void DGSReader::read(std::string path, GraphEventProxy& Gproxy) {
             std::vector<std::string> split = Aux::StringTools::split(line);
             std::string tag = split[0];
 
-            //std::unordered_map<std::string, node> edgeNames;
-
             if (tag.compare("st") == 0 && split.size() == 2) { // clock
                 Gproxy.timeStep();
 
@@ -67,10 +68,7 @@ void DGSReader::read(std::string path, GraphEventProxy& Gproxy) {
                     std::string categoriesCommaSeparated = categoriesFullStringSplit[1]; // Example: cond-mat.stat-mech, q-fin.ST
                     std::vector<std::string> categories = Aux::StringTools::split(categoriesCommaSeparated, ',');
 
-                    std::vector<std::string> currentNodeCategories;
-                    for (std::string category : categories) {
-                        currentNodeCategories.push_back(category);
-                    }
+                    std::vector<std::string> currentNodeCategories(categories.begin(), categories.end());
                     nodeCategories.push_back(currentNodeCategories);
 
                     std::string dateFullString = split[3]; // Example: date="08-1997"
@@ -78,11 +76,6 @@ void DGSReader::read(std::string path, GraphEventProxy& Gproxy) {
                     std::string date = dateFullStringSplit[1];
                     nodeDates.push_back(date);
                 }
-
-
-
-
-
             } else if (tag.compare("ae") == 0 && split.size() >= 4) { // add edge
                 std::string edge_from = split[2];
                 std::string edge_to = split[3];
@@ -119,23 +112,14 @@ void DGSReader::read(std::string path, GraphEventProxy& Gproxy) {
                 std::string edge_to = edgesSplit[1];
                 node u = nodeNames[edge_from];
                 node v = nodeNames[edge_to];
-                //			TRACE("u: " , edge_from , " " , u);
-                //			TRACE("v: " , edge_to , " " , v);
-
                 Gproxy.removeEdge(u, v);
             }
-
-
-
-
-
         }
 
         std::cout << "nodeNames length " << nodeNames.size();
         std::map<std::string, node> ordered(nodeNames.begin(), nodeNames.end());
         for(auto it = ordered.begin(); it != ordered.end(); ++it)
             std::cout << " contents " << it->second << std::endl;
-
     }
 }
 
