@@ -2,24 +2,22 @@
  * LinkPredictor.cpp
  *
  *  Created on: 28.02.2015
- *      Author: Kolja Esders (kolja.esders@student.kit.edu)
+ *      Author: Kolja Esders
  */
 
 #include <algorithm>
 
-#include <networkit/linkprediction/LinkPredictor.hpp>
 #include <networkit/auxiliary/Log.hpp>
 #include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/linkprediction/LinkPredictor.hpp>
 
 #include <omp.h>
 
 namespace NetworKit {
 
-LinkPredictor::LinkPredictor() : G(nullptr), validCache(false) {
-}
+LinkPredictor::LinkPredictor() : G(nullptr), validCache(false) {}
 
-LinkPredictor::LinkPredictor(const Graph& G) : G(&G), validCache(false) {
-}
+LinkPredictor::LinkPredictor(const Graph& G) : G(&G), validCache(false) {}
 
 void LinkPredictor::setGraph(const Graph& newGraph) {
   G = &newGraph;
@@ -44,7 +42,7 @@ double LinkPredictor::run(node u, node v) {
   } else if (G->isDirected()) {
     throw std::invalid_argument("Only undirected graphs accepted.");
   } else if (u == v) {
-    // Default behaviour for self-loops
+    // Default behavior for self-loops
     return 0;
   }
   return runImpl(u, v);
