@@ -5,18 +5,16 @@
  *      Author: cls
  */
 
-#include <networkit/structures/Partition.hpp>
-#include <networkit/auxiliary/Parallel.hpp>
 #include <algorithm>
 #include <atomic>
 #include <memory>
 
+#include <networkit/auxiliary/Parallel.hpp>
+#include <networkit/structures/Partition.hpp>
+
 namespace NetworKit {
 
-Partition::Partition() : z(0), omega(0), data(0) {
-
-}
-
+Partition::Partition() : z(0), omega(0), data(0) {}
 
 Partition::Partition(const std::vector<index>& data) : z(data.size()), omega(), data(data) {
     auto max_elem = *std::max_element(data.begin(), data.end());
@@ -24,13 +22,9 @@ Partition::Partition(const std::vector<index>& data) : z(data.size()), omega(),
 }
 
 
-Partition::Partition(index z) : z(z), omega(0), data(z, none) {  //z(z-1);data(z,none);
+Partition::Partition(index z) : z(z), omega(0), data(z, none) {}
 
-}
-
-Partition::Partition(index z, index defaultValue) : z(z), omega(0), data(z, defaultValue) {  //z(z-1);data(z,none);
-
-}
+Partition::Partition(index z, index defaultValue) : z(z), omega(0), data(z, defaultValue) {}
 
 void Partition::allToSingletons() {
     setUpperBound(numberOfElements());
@@ -53,22 +47,6 @@ index Partition::mergeSubsets(index s, index t) {
     }
     return none; // no new cluster formed
 }
-/*
-bool Partition::isOnePartition(Graph& G) { //FIXME what for is elements needed? const std::set<index>& elements
-    index one = data[0];	// first subset id should be equal to all others
-    // TODO: use iterator forEntries and pair-wise comparison?
-    for (index e = 0; e < this->z; ++e) { // FIXME constructor initializes data with z+1, so <= is necessary.
-        if (data[e] != one) {
-            return false;
-        }
-    }
-    return true;
-}*/
-
-/*bool Partition::isSingletonPartition(Graph& G) const { //FIXME what for is elements needed? const std::set<index>& elements
-    return (numberOfElements() == numberOfSubsets());
-}
-*/
 
 count Partition::numberOfSubsets() const {
     auto n = upperBound();
@@ -121,6 +99,7 @@ void Partition::compact(bool useTurbo) {
 std::vector<count> Partition::subsetSizes() const {
     std::vector<count> sizes;
     std::map<index, count> map = this->subsetSizeMap();
+    sizes.reserve(map.size());
     for (auto kv : map) {
         sizes.push_back(kv.second);
     }
@@ -139,7 +118,7 @@ std::map<index, count> Partition::subsetSizeMap() const {
     return subset2size;
 }
 
-std::set<index> Partition::getMembers(const index s) const {
+std::set<index> Partition::getMembers(index s) const {
     assert (s <= omega);
     std::set<index> subset;
     for (index e = 0; e < this->z; ++e) {
@@ -163,7 +142,7 @@ std::set<std::set<index> > Partition::getSubsets() const {
     });
 
     std::set<std::set<index> > subsets;
-    for (auto set : table) {
+    for (const auto &set : table) {
         if (set.size() > 0) {
             subsets.insert(set);
         }
