@@ -28,3 +28,5 @@ class Test_CommunityDetection(unittest.TestCase):
 		hierarchy = community.CutClustering.getClusterHierarchy(jazz)
 		self.assertEqual(3, len(hierarchy))
 
+if __name__ == "__main__":
+	unittest.main()
